package com.bpcl.lpg.core.service.impl;

import org.slf4j.LoggerFactory;
import org.springframework.http.HttpStatus;
import com.bpcl.lpg.core.enums.GenericStatusEnum;
import de.hybris.platform.b2b.model.B2BRegistrationModel;
import com.bpcl.core.model.BpclQrcodeDetailsModel;
import de.hybris.platform.core.model.user.CustomerModel;
import com.bpcl.core.model.TransactionHistoryModel;
import com.bpcl.core.model.SAPB2BUnitModel;
import de.hybris.platform.core.model.user.EmployeeModel;
import java.util.List;
import java.util.ArrayList;
import com.bpcl.core.model.BpclBankAccountDetailsModel;
import java.util.Iterator;
import java.util.Date;
import de.hybris.platform.b2b.model.B2BCustomerModel;
import com.bpcl.lpg.core.model.LPGConnectionModel;
import de.hybris.platform.servicelayer.exceptions.AmbiguousIdentifierException;
import de.hybris.platform.core.model.user.UserModel;
import com.bpcl.lpg.core.model.LPGExemptConnectionModel;
import com.bpcl.lpg.core.model.LPGDomesticConnectionModel;
import java.util.Set;
import com.bpcl.lpg.core.enums.LpgConsumerStatusEnum;
import com.bpcl.core.enums.BpclBusinessUnit;
import com.bpcl.core.enums.ProgramTypeEnum;
import com.bpcl.core.enums.BpclBusinessProgram;
import com.bpcl.lpg.core.model.LPGCommercialConnectionModel;
import com.bpcl.core.model.BPCLAccountModel;
import java.util.HashSet;
import org.apache.commons.lang.StringUtils;
import java.util.Objects;
import com.bpcl.lpg.facades.data.LpgResponseBodyData;
import java.util.Collection;
import org.apache.commons.collections.CollectionUtils;
import com.bpcl.lpg.core.model.NewConnectionsModel;
import java.util.Map;
import com.bpcl.lpg.facades.data.LpgResponseData;
import de.hybris.platform.b2b.model.B2BUnitModel;
import com.bpcl.lpg.core.pojo.RspResponseData;
import de.hybris.platform.commerceservices.customer.dao.CustomerDao;
import com.bpcl.core.registration.dao.BPCLB2BRegistrationDao;
import de.hybris.platform.search.restriction.SearchRestrictionService;
import javax.annotation.Resource;
import de.hybris.platform.servicelayer.search.FlexibleSearchService;
import de.hybris.platform.servicelayer.keygenerator.KeyGenerator;
import com.bpcl.core.customer.service.BpclCustomerService;
import de.hybris.platform.servicelayer.user.UserService;
import com.bpcl.core.model.BPCLCustomerModel;
import com.bpcl.core.model.BPCLB2BUnitModel;
import de.hybris.platform.b2b.services.B2BUnitService;
import de.hybris.platform.servicelayer.model.ModelService;
import org.slf4j.Logger;
import com.bpcl.lpg.core.service.LpgCustomerService;
import com.bpcl.core.customer.service.impl.DefaultBpclCustomerService;

public class LpgCustomerServiceImpl extends DefaultBpclCustomerService implements LpgCustomerService
{
    private static final Logger LOG;
    private static final String SPACE = " ";
    private static final String DUMMY_B2BUNIT = "Dummy";
    private static final String LPGB2C_UNIT = "LPGB2CUnit";
    private static final String LPGB2B_UNIT = "LPGB2BUnit";
    private ModelService modelService;
    private B2BUnitService<BPCLB2BUnitModel, BPCLCustomerModel> b2bUnitService;
    private UserService userService;
    private BpclCustomerService bpclCustomerService;
    private KeyGenerator lpgAccountIdGenerator;
    @Resource(name = "flexibleSearchService")
    private FlexibleSearchService flexibleSearchService;
    @Resource(name = "searchRestrictionService")
    private SearchRestrictionService searchRestrictionService;
    @Resource(name = "BPCLB2BRegistrationDao")
    private BPCLB2BRegistrationDao bpclb2bRegistrationDao;
    
    public LpgCustomerServiceImpl(final CustomerDao customerDao, final String regexp) {
        super(customerDao, regexp);
    }
    
    public BPCLCustomerModel createCustomer(final RspResponseData rspResponseData, final String contactNumber) {
        final BPCLCustomerModel customerModel = (BPCLCustomerModel)this.getModelService().create((Class)BPCLCustomerModel.class);
        this.setBasicDetails(rspResponseData, contactNumber, customerModel);
        customerModel.setDefaultB2BUnit((B2BUnitModel)this.getB2bUnitService().getUnitForUid("Dummy"));
        customerModel.setEmail("lpgtestemail@gmail.com");
        customerModel.setLoginDisabled(true);
        this.getModelService().save((Object)customerModel);
        this.setTemporaryCredentialOnOTPValidation(customerModel.getUid());
        LpgCustomerServiceImpl.LOG.info("Successfully created new customer :: {} ", customerModel.getUid());
        return customerModel;
    }
    
    public void createNewConnection(final LpgResponseData lpgResponseData, final Map<String, String> customerInfo) {
        final NewConnectionsModel connectionModel = (NewConnectionsModel)this.getModelService().create((Class)NewConnectionsModel.class);
        this.populateConnectionData(connectionModel, lpgResponseData, customerInfo);
        this.getModelService().save((Object)connectionModel);
    }
    
    private void populateConnectionData(final NewConnectionsModel connectionModel, final LpgResponseData lpgResponseData, final Map<String, String> customerInfo) {
        LpgResponseBodyData data = null;
        if (CollectionUtils.isNotEmpty((Collection)lpgResponseData.getData())) {
            data = lpgResponseData.getData().get(0);
        }
        if (data != null) {
            connectionModel.setStatus(this.getStatus(data.getRequestStatusCode()));
            final long kycId = data.getRegistrationRefNo();
            connectionModel.setKycId(Objects.isNull(kycId) ? "" : String.valueOf(kycId));
        }
        connectionModel.setMobileNo((String)customerInfo.get("mobileNo"));
        connectionModel.setEmailId((String)customerInfo.get("emailId;"));
        connectionModel.setDescription(lpgResponseData.getReturnMsg());
        connectionModel.setName(this.populateConsumerName(customerInfo));
    }
    
    private String populateConsumerName(final Map<String, String> customerInfo) {
        final StringBuilder sb = new StringBuilder(customerInfo.get("firstName"));
        if (StringUtils.isNotBlank((String)customerInfo.get("middleName"))) {
            sb.append(" ").append(customerInfo.get("middleName"));
        }
        sb.append(" ").append(customerInfo.get("lastName"));
        return sb.toString();
    }
    
    private void setBasicDetails(final RspResponseData rspResponseData, final String contactNumber, final BPCLCustomerModel customerModel) {
        customerModel.setUid(contactNumber);
        customerModel.setContactNumber(contactNumber);
        customerModel.setCustomerID(contactNumber);
        customerModel.setName(rspResponseData.getConsumerName());
        this.setLPGConnection(rspResponseData, customerModel);
    }
    
    private void setLPGConnection(final RspResponseData rspResponseData, final BPCLCustomerModel customerModel) {
        final Set<BPCLAccountModel> accounts = new HashSet<BPCLAccountModel>();
        if (StringUtils.isNotBlank(rspResponseData.getAddl3())) {
            if (rspResponseData.getAddl3().equalsIgnoreCase("COMMERCIAL")) {
                final LPGCommercialConnectionModel lpgCommercialConnectionModel = (LPGCommercialConnectionModel)this.getModelService().create((Class)LPGCommercialConnectionModel.class);
                lpgCommercialConnectionModel.setLpgId(rspResponseData.getLpgId());
                lpgCommercialConnectionModel.setName(BpclBusinessProgram.LPG_COMMERCIAL.getCode());
                lpgCommercialConnectionModel.setConsumerID(rspResponseData.getConsumerId());
                lpgCommercialConnectionModel.setConsumerNumber(rspResponseData.getConsumerNumber());
                lpgCommercialConnectionModel.setDistId(rspResponseData.getDistributorCode());
                lpgCommercialConnectionModel.setConnectionType(rspResponseData.getAddl4());
                lpgCommercialConnectionModel.setProgramType(ProgramTypeEnum.BUSINESS);
                lpgCommercialConnectionModel.setBpclBusinessUnit(BpclBusinessUnit.LPG);
                lpgCommercialConnectionModel.setB2bUnit((B2BUnitModel)this.getB2bUnitService().getUnitForUid("LPGB2BUnit"));
                if (StringUtils.isNotBlank(rspResponseData.getAddl5())) {
                    lpgCommercialConnectionModel.setConsumerStatus(LpgConsumerStatusEnum.valueOf(rspResponseData.getAddl5()));
                }
                lpgCommercialConnectionModel.setApplicationNumber(this.getLpgAccountIdGenerator().generate().toString());
                this.getModelService().save((Object)lpgCommercialConnectionModel);
                if (CollectionUtils.isNotEmpty((Collection)customerModel.getBpclAccounts())) {
                    accounts.addAll(customerModel.getBpclAccounts());
                }
                accounts.add((BPCLAccountModel)lpgCommercialConnectionModel);
                customerModel.setBpclAccounts((Set)accounts);
            }
            else if (rspResponseData.getAddl3().equalsIgnoreCase("Domestic")) {
                final LPGDomesticConnectionModel lpgDomesticConnectionModel = (LPGDomesticConnectionModel)this.getModelService().create((Class)LPGDomesticConnectionModel.class);
                lpgDomesticConnectionModel.setLpgId(rspResponseData.getLpgId());
                lpgDomesticConnectionModel.setName(BpclBusinessProgram.LPG_DOMESTIC.getCode());
                lpgDomesticConnectionModel.setConsumerID(rspResponseData.getConsumerId());
                lpgDomesticConnectionModel.setConsumerNumber(rspResponseData.getConsumerNumber());
                lpgDomesticConnectionModel.setDistId(rspResponseData.getDistributorCode());
                lpgDomesticConnectionModel.setConnectionType(rspResponseData.getAddl4());
                lpgDomesticConnectionModel.setProgramType(ProgramTypeEnum.PERSONAL);
                lpgDomesticConnectionModel.setBpclBusinessUnit(BpclBusinessUnit.LPG);
                lpgDomesticConnectionModel.setB2bUnit((B2BUnitModel)this.getB2bUnitService().getUnitForUid("LPGB2CUnit"));
                if (StringUtils.isNotBlank(rspResponseData.getAddl5())) {
                    lpgDomesticConnectionModel.setConsumerStatus(LpgConsumerStatusEnum.valueOf(rspResponseData.getAddl5()));
                }
                lpgDomesticConnectionModel.setApplicationNumber(this.getLpgAccountIdGenerator().generate().toString());
                this.getModelService().save((Object)lpgDomesticConnectionModel);
                if (CollectionUtils.isNotEmpty((Collection)customerModel.getBpclAccounts())) {
                    accounts.addAll(customerModel.getBpclAccounts());
                }
                accounts.add((BPCLAccountModel)lpgDomesticConnectionModel);
                customerModel.setBpclAccounts((Set)accounts);
            }
            else if (rspResponseData.getAddl3().equalsIgnoreCase("Exempted")) {
                final LPGExemptConnectionModel lpgExemptConnectionModel = (LPGExemptConnectionModel)this.getModelService().create((Class)LPGExemptConnectionModel.class);
                lpgExemptConnectionModel.setLpgId(rspResponseData.getLpgId());
                lpgExemptConnectionModel.setName(BpclBusinessProgram.LPG_EXEMPTED.getCode());
                lpgExemptConnectionModel.setConsumerID(rspResponseData.getConsumerId());
                lpgExemptConnectionModel.setConsumerNumber(rspResponseData.getConsumerNumber());
                lpgExemptConnectionModel.setDistId(rspResponseData.getDistributorCode());
                lpgExemptConnectionModel.setConnectionType(rspResponseData.getAddl4());
                lpgExemptConnectionModel.setProgramType(ProgramTypeEnum.PERSONAL);
                lpgExemptConnectionModel.setBpclBusinessUnit(BpclBusinessUnit.LPG);
                if (StringUtils.isNotBlank(rspResponseData.getAddl5())) {
                    lpgExemptConnectionModel.setConsumerStatus(LpgConsumerStatusEnum.valueOf(rspResponseData.getAddl5()));
                }
                lpgExemptConnectionModel.setApplicationNumber(this.getLpgAccountIdGenerator().generate().toString());
                this.getModelService().save((Object)lpgExemptConnectionModel);
                if (CollectionUtils.isNotEmpty((Collection)customerModel.getBpclAccounts())) {
                    accounts.addAll(customerModel.getBpclAccounts());
                }
                accounts.add((BPCLAccountModel)lpgExemptConnectionModel);
                customerModel.setBpclAccounts((Set)accounts);
            }
        }
    }
    
    public String getUserId() {
        final UserModel currentUser = this.getUserService().getCurrentUser();
        if (currentUser instanceof BPCLCustomerModel) {
            return currentUser.getUid();
        }
        if (LpgCustomerServiceImpl.LOG.isDebugEnabled()) {
            LpgCustomerServiceImpl.LOG.debug("Unable to found the User");
        }
        return "";
    }
    
    public void updateCustomerIdForLoggedInUser(final String newContactNumber) throws AmbiguousIdentifierException {
        final BPCLCustomerModel customer = this.getCurrentCustomer();
        this.changeLogin(customer, newContactNumber);
    }
    
    public void updateCustomerIdForAnonymousUser(final String currentContactNumber, final String newContactNumber) {
        final BPCLCustomerModel customer = (BPCLCustomerModel)this.userService.getUserForUID(currentContactNumber);
        this.changeLogin(customer, newContactNumber);
    }
    
    public BPCLCustomerModel getCustomerByLpgId(final String lpgId) {
        return this.getBpclCustomerDao().findCustomerByLpgId(lpgId);
    }
    
    public BPCLCustomerModel getCustomerByConsumerDetails(final String consumerNumber, final String distCode) {
        return this.getBpclCustomerDao().findCustomerByConsumerDetails(consumerNumber, distCode);
    }
    
    public void updateDistCodeForCustomer(final String contactNumber, final String distributorCode) {
        final BPCLCustomerModel customer = (BPCLCustomerModel)this.userService.getUserForUID(contactNumber);
        if (Objects.nonNull(customer)) {
            final Set<BPCLAccountModel> accounts = customer.getBpclAccounts();
            if (CollectionUtils.isNotEmpty((Collection)accounts)) {
                final LPGConnectionModel lpgConnectionModel = this.getBpclCustomerService().getLPGConnectionForCustomer(customer);
                if (!StringUtils.equalsIgnoreCase(distributorCode, lpgConnectionModel.getDistId())) {
                    lpgConnectionModel.setDistId(distributorCode);
                    this.modelService.save((Object)lpgConnectionModel);
                }
            }
        }
    }
    
    public void createCustomerLPGConnection(final RspResponseData rspResponseData, final BPCLCustomerModel customerModel) {
        if (null != customerModel) {
            this.setLPGConnection(rspResponseData, customerModel);
            this.modelService.save((Object)customerModel);
        }
    }
    
    public LPGConnectionModel findLPGConnectionByLpgId(final String lpgID, final String mobileNumber) {
        return this.getBpclCustomerDao().findLPGConnectionByLpgId(lpgID, mobileNumber);
    }
    
    public void copyLPGAccount(final BPCLCustomerModel sourceCustomer, final BPCLCustomerModel targetCustomer) {
        final Set<BPCLAccountModel> targetAccounts = CollectionUtils.isEmpty((Collection)targetCustomer.getBpclAccounts()) ? new HashSet<BPCLAccountModel>() : targetCustomer.getBpclAccounts();
        LpgCustomerServiceImpl.LOG.info("New Customer accounts {}", targetAccounts.size() + "for Target Customer " + targetCustomer.getUid());
        final Set<BPCLAccountModel> sourceAccounts = this.getLPGAccount(sourceCustomer);
        LpgCustomerServiceImpl.LOG.info("Old Customer accounts {}", sourceAccounts.size() + "for Source Customer " + sourceCustomer.getUid());
        final Set<BPCLAccountModel> bothAccounts = new HashSet<BPCLAccountModel>();
        bothAccounts.addAll(targetAccounts);
        if (sourceAccounts.isEmpty()) {
            LpgCustomerServiceImpl.LOG.error("Unable to find the account for the customer {}", sourceCustomer.getUid());
        }
        for (final BPCLAccountModel bpclAccount : sourceAccounts) {
            bpclAccount.setBpclCustomer((B2BCustomerModel)targetCustomer);
            if (bpclAccount instanceof LPGConnectionModel) {
                LpgCustomerServiceImpl.LOG.info("LPG connection accout set rsp cycle null.");
                final LPGConnectionModel lpgConnectionModel = (LPGConnectionModel)bpclAccount;
                lpgConnectionModel.setRspPerCycle((Double)null);
                lpgConnectionModel.setLastUpdatedRspPerCycle((Date)null);
                bothAccounts.add((BPCLAccountModel)lpgConnectionModel);
            }
            else {
                bothAccounts.add(bpclAccount);
            }
        }
        targetCustomer.setBpclAccounts((Set)bothAccounts);
        this.modelService.save((Object)targetCustomer);
        this.modelService.refresh((Object)targetCustomer);
        this.setCustomerData(sourceCustomer, targetCustomer);
        LpgCustomerServiceImpl.LOG.info("Old before save customer name {}", sourceCustomer.getName());
        this.modelService.save((Object)sourceCustomer);
        this.modelService.refresh((Object)sourceCustomer);
        LpgCustomerServiceImpl.LOG.info("Old after save customer name {}", sourceCustomer.getName());
        LpgCustomerServiceImpl.LOG.info("New before save customer name {}", targetCustomer.getName());
        this.modelService.save((Object)targetCustomer);
        this.modelService.refresh((Object)targetCustomer);
        LpgCustomerServiceImpl.LOG.info("New after save customer name {}", targetCustomer.getName());
    }
    
    public void setCustomerData(final BPCLCustomerModel sourceCustomer, final BPCLCustomerModel targetCustomer) {
        LpgCustomerServiceImpl.LOG.info("customer name old {} new customer {}", sourceCustomer.getName(), targetCustomer.getName());
        LpgCustomerServiceImpl.LOG.info("set Bpcl Bank Account Details");
        if (sourceCustomer.getBpclBankAccountDetails() != null) {
            final BpclBankAccountDetailsModel bpclBankAccountDetailsModel = sourceCustomer.getBpclBankAccountDetails();
            bpclBankAccountDetailsModel.setMobileNumber(targetCustomer.getUid());
            this.modelService.save((Object)bpclBankAccountDetailsModel);
            targetCustomer.setBpclBankAccountDetails(bpclBankAccountDetailsModel);
            sourceCustomer.setBpclBankAccountDetails((BpclBankAccountDetailsModel)null);
        }
        targetCustomer.setValidBankDetails(sourceCustomer.getValidBankDetails());
        LpgCustomerServiceImpl.LOG.info("set Shop Address");
        if (sourceCustomer.getShopAddress() != null) {
            targetCustomer.setShopAddress(sourceCustomer.getShopAddress());
        }
        LpgCustomerServiceImpl.LOG.info("set uid {}", targetCustomer.getUid());
        if (targetCustomer.getUid() != null) {
            targetCustomer.setCustomerID(targetCustomer.getUid());
        }
        LpgCustomerServiceImpl.LOG.info("set Email {}", sourceCustomer.getEmail());
        if (sourceCustomer.getEmail() != null) {
            targetCustomer.setEmail(sourceCustomer.getEmail());
        }
        LpgCustomerServiceImpl.LOG.info("set Email {}", sourceCustomer.getEmail());
        if (sourceCustomer.getOptForPromotion() != null) {
            targetCustomer.setOptForPromotion(sourceCustomer.getOptForPromotion());
        }
        LpgCustomerServiceImpl.LOG.info("set Primary User Mobile Number {}", sourceCustomer.getPrimaryUserMobileNumber());
        if (sourceCustomer.getPrimaryUserMobileNumber() != null) {
            targetCustomer.setPrimaryUserMobileNumber(sourceCustomer.getPrimaryUserMobileNumber());
        }
        LpgCustomerServiceImpl.LOG.info("set Primary User Designation {}", sourceCustomer.getPrimaryUserDesignation());
        if (sourceCustomer.getPrimaryUserDesignation() != null) {
            targetCustomer.setPrimaryUserDesignation(sourceCustomer.getPrimaryUserDesignation());
        }
        LpgCustomerServiceImpl.LOG.info("set Work Shop Category {}", sourceCustomer.getWorkShopCategory());
        if (sourceCustomer.getWorkShopCategory() != null) {
            targetCustomer.setWorkShopCategory(sourceCustomer.getWorkShopCategory());
        }
        LpgCustomerServiceImpl.LOG.info("set Work Shop Sub Category {}", sourceCustomer.getWorkShopSubCategory());
        if (sourceCustomer.getWorkShopSubCategory() != null) {
            targetCustomer.setWorkShopSubCategory(sourceCustomer.getWorkShopSubCategory());
        }
        LpgCustomerServiceImpl.LOG.info("set NotificationChannels size {}", (Object)sourceCustomer.getNotificationChannels().size());
        if (CollectionUtils.isNotEmpty((Collection)sourceCustomer.getNotificationChannels())) {
            targetCustomer.setNotificationChannels(sourceCustomer.getNotificationChannels());
        }
        LpgCustomerServiceImpl.LOG.info("set Shop Name {}", sourceCustomer.getShopName());
        if (sourceCustomer.getShopName() != null) {
            targetCustomer.setShopName(sourceCustomer.getShopName());
        }
        LpgCustomerServiceImpl.LOG.info("set Sub Retailers size {}", (Object)sourceCustomer.getSubRetailers().size());
        if (CollectionUtils.isNotEmpty((Collection)sourceCustomer.getSubRetailers())) {
            targetCustomer.setSubRetailers(sourceCustomer.getSubRetailers());
            sourceCustomer.setSubRetailers((List)new ArrayList());
        }
        LpgCustomerServiceImpl.LOG.info("set Is SubUser {}", sourceCustomer.getIsSubUser());
        if (sourceCustomer.getIsSubUser() != null) {
            targetCustomer.setIsSubUser(sourceCustomer.getIsSubUser());
        }
        LpgCustomerServiceImpl.LOG.info("set Customer Type {}", sourceCustomer.getCustomerType());
        if (sourceCustomer.getCustomerType() != null) {
            targetCustomer.setCustomerType(sourceCustomer.getCustomerType());
        }
        LpgCustomerServiceImpl.LOG.info("set name {}", sourceCustomer.getName());
        if (targetCustomer.getName() == null && sourceCustomer.getName() != null) {
            targetCustomer.setName(sourceCustomer.getName());
        }
        LpgCustomerServiceImpl.LOG.info("set so");
        if (Objects.nonNull(sourceCustomer.getSo())) {
            final EmployeeModel employeeModel = sourceCustomer.getSo();
            sourceCustomer.setSo((EmployeeModel)null);
            targetCustomer.setSo(employeeModel);
        }
        LpgCustomerServiceImpl.LOG.info("set Enrolled By");
        if (Objects.nonNull(sourceCustomer.getEnrolledBy())) {
            final B2BCustomerModel b2bCustomerModel = sourceCustomer.getEnrolledBy();
            sourceCustomer.setEnrolledBy((B2BCustomerModel)null);
            targetCustomer.setEnrolledBy(b2bCustomerModel);
        }
        LpgCustomerServiceImpl.LOG.info("set Distributor");
        if (Objects.nonNull(sourceCustomer.getLubesDistributor())) {
            final SAPB2BUnitModel sapb2BUnitModel = sourceCustomer.getLubesDistributor();
            sourceCustomer.setLubesDistributor((SAPB2BUnitModel)null);
            targetCustomer.setLubesDistributor(sapb2BUnitModel);
        }
        LpgCustomerServiceImpl.LOG.info("set Transaction History size {}", (Object)sourceCustomer.getTransactionHistory().size());
        final Set<TransactionHistoryModel> transactions = new HashSet<TransactionHistoryModel>();
        if (CollectionUtils.isNotEmpty((Collection)sourceCustomer.getTransactionHistory())) {
            for (final TransactionHistoryModel trans : sourceCustomer.getTransactionHistory()) {
                trans.setCustomer((CustomerModel)targetCustomer);
                transactions.add(trans);
            }
            targetCustomer.setTransactionHistory((Set)transactions);
            sourceCustomer.setTransactionHistory((Set)new HashSet());
        }
        LpgCustomerServiceImpl.LOG.info("set BpclQrcode Details");
        final Set<BpclQrcodeDetailsModel> qrCodes = new HashSet<BpclQrcodeDetailsModel>();
        if (CollectionUtils.isNotEmpty((Collection)sourceCustomer.getBpclQrcodeDetails())) {
            for (final BpclQrcodeDetailsModel qrcode : sourceCustomer.getBpclQrcodeDetails()) {
                qrcode.setCustomer((CustomerModel)targetCustomer);
                qrCodes.add(qrcode);
            }
            targetCustomer.setBpclQrcodeDetails((Set)qrCodes);
            sourceCustomer.setBpclQrcodeDetails((Set)new HashSet());
        }
        try {
            LpgCustomerServiceImpl.LOG.info("set B2B Registration");
            final B2BRegistrationModel registration = new B2BRegistrationModel();
            registration.setTelephone(sourceCustomer.getUid());
            final B2BRegistrationModel b2bRegistrationModels = this.bpclb2bRegistrationDao.getRegistration(sourceCustomer.getUid());
            if (b2bRegistrationModels != null) {
                b2bRegistrationModels.setTelephone(targetCustomer.getUid());
                this.modelService.save((Object)b2bRegistrationModels);
                LpgCustomerServiceImpl.LOG.info("set B2B Registration done.");
            }
        }
        catch (final Exception e) {
            LpgCustomerServiceImpl.LOG.error("Exception occurred while user B2B Registration Model", e.getCause());
        }
    }
    
    public void removeLPGAccount(final BPCLCustomerModel customer) {
        if (org.apache.commons.collections4.CollectionUtils.isNotEmpty((Collection)customer.getBpclAccounts())) {
            final Iterator<BPCLAccountModel> iterator = customer.getBpclAccounts().iterator();
            while (iterator.hasNext()) {
                final BPCLAccountModel account = iterator.next();
                if (account instanceof LPGConnectionModel) {
                    LpgCustomerServiceImpl.LOG.debug("Removing the account {} for the customer {}", account.getApplicationNumber(), customer.getUid());
                    iterator.remove();
                }
            }
            this.modelService.save((Object)customer);
        }
        else {
            LpgCustomerServiceImpl.LOG.info("No accounts found for the customer {}", customer.getUid());
        }
    }
    
    private void changeLogin(final BPCLCustomerModel customer, final String newContactNumber) {
        this.searchRestrictionService.disableSearchRestrictions();
        try {
            if (this.userService.isUserExisting(newContactNumber)) {
                final BPCLCustomerModel newUser = (BPCLCustomerModel)this.userService.getUserForUID(newContactNumber, (Class)BPCLCustomerModel.class);
                this.copyLPGAccount(customer, newUser);
                this.updatePrevUsedNumbers(newUser, customer.getUid());
                this.modelService.save((Object)newUser);
            }
            else {
                final String oldUid = customer.getUid();
                customer.setUid(newContactNumber);
                customer.setOriginalUid(newContactNumber);
                customer.setCustomerID(newContactNumber);
                customer.setContactNumber(newContactNumber);
                this.updatePrevUsedNumbers(customer, oldUid);
                this.getModelService().save((Object)customer);
            }
        }
        catch (final Exception exception) {
            LpgCustomerServiceImpl.LOG.error("Exception occurred while changing the login", exception.getCause());
        }
        this.searchRestrictionService.enableSearchRestrictions();
    }
    
    private void updatePrevUsedNumbers(final BPCLCustomerModel customer, final String oldUid) {
        final List<String> prevNumbersList = new ArrayList<String>(customer.getPrevUsedNumbers());
        prevNumbersList.add(oldUid);
        customer.setPrevUsedNumbers((List)prevNumbersList);
    }
    
    private Set<BPCLAccountModel> getLPGAccount(final BPCLCustomerModel oldCustomer) {
        LpgCustomerServiceImpl.LOG.info("inside getLPGAccount : account size is " + oldCustomer.getBpclAccounts().size() + "for customer " + oldCustomer.getUid());
        return CollectionUtils.isEmpty((Collection)oldCustomer.getBpclAccounts()) ? new HashSet<BPCLAccountModel>() : oldCustomer.getBpclAccounts();
    }
    
    private GenericStatusEnum getStatus(final int returnCode) {
        return (HttpStatus.OK.value() == returnCode) ? GenericStatusEnum.SUCCESS : GenericStatusEnum.FAILED;
    }
    
    public ModelService getModelService() {
        return this.modelService;
    }
    
    public void setModelService(final ModelService modelService) {
        this.modelService = modelService;
    }
    
    public B2BUnitService<BPCLB2BUnitModel, BPCLCustomerModel> getB2bUnitService() {
        return this.b2bUnitService;
    }
    
    public void setB2bUnitService(final B2BUnitService<BPCLB2BUnitModel, BPCLCustomerModel> b2bUnitService) {
        this.b2bUnitService = b2bUnitService;
    }
    
    public UserService getUserService() {
        return this.userService;
    }
    
    public void setUserService(final UserService userService) {
        this.userService = userService;
    }
    
    public BpclCustomerService getBpclCustomerService() {
        return this.bpclCustomerService;
    }
    
    public void setBpclCustomerService(final BpclCustomerService bpclCustomerService) {
        this.bpclCustomerService = bpclCustomerService;
    }
    
    public KeyGenerator getLpgAccountIdGenerator() {
        return this.lpgAccountIdGenerator;
    }
    
    public void setLpgAccountIdGenerator(final KeyGenerator lpgAccountIdGenerator) {
        this.lpgAccountIdGenerator = lpgAccountIdGenerator;
    }
    
    static {
        LOG = LoggerFactory.getLogger(LpgCustomerServiceImpl.class);
    }
}
